@@ -1,7 +1,8 @@
 use std::error;
 use std::fmt;
+use thiserror::{ Error as ThisError };
 
-#[derive(Debug, Clone)]
+#[derive(ThisError, Debug, Clone)]
 pub struct ResponseContent<T> {
     pub status: reqwest::StatusCode,
     pub content: String,
