@@ -46,6 +46,8 @@ pub mod device_calibration_request;
 pub use self::device_calibration_request::DeviceCalibrationRequest;
 pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
+pub mod error_detail;
+pub use self::error_detail::ErrorDetail;
 pub mod event_source_enum;
 pub use self::event_source_enum::EventSourceEnum;
 pub mod event_type0c4_enum;
@@ -56,8 +58,6 @@ pub mod experiment_device_config;
 pub use self::experiment_device_config::ExperimentDeviceConfig;
 pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
-pub mod inline_response_default;
-pub use self::inline_response_default::InlineResponseDefault;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
